package com.miaxis.feign.service;

import com.miaxis.common.config.FeignConfig;
import com.miaxis.feign.dto.WxTicket;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 微信公众号接口
 * @author wwl
 * @version 1.0
 * @date 2021/10/20 14:59
 */
@FeignClient(name="wxSendService",
        url = "https://api.weixin.qq.com/cgi-bin",configuration = FeignConfig.class)
public interface IWxSendService {


    /**
     *  获取token
     * @param grant_type
     * @param appid 第三方用户唯一凭证
     * @param secret 第三方用户唯一凭证密钥，即appsecret
     * @return
     */
    @GetMapping(value = "/token")
    String getAccessToken(@RequestParam("grant_type") String grant_type,
                          @RequestParam("appid") String appid,
                          @RequestParam("secret") String secret);


    /**
     * 生成带参数二维码接口
     *      -文档链接：https://developers.weixin.qq.com/doc/offiaccount/Account_Management/Generating_a_Parametric_QR_Code.html
     * @param accessToken
     * @param wxTicket:二维码参数
     * @return
     */
    @PostMapping(value = "/qrcode/create")
    String generateTicket(@RequestParam("access_token")String accessToken, WxTicket wxTicket);


}
