package com.miaxis.wx.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.redis.RedisCache;
import com.miaxis.feign.service.IWxSendService;
import com.miaxis.wx.service.IWxGzhService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.concurrent.TimeUnit;

/**
 * 微信公众号业务层
 * @author wwl
 * @version 1.0
 * @date 2021/10/20 14:57
 */
@Service
@Slf4j
public class WxGzhServiceImpl implements IWxGzhService {


    @Resource
    private RedisCache redisCache;

    @Resource
    private IWxSendService wxSendService;

    @Value("${app.appid}")
    private String appid;

    @Value("${app.appSecret}")
    private String secret;


    @Override
    public String getGzhToken() {
        Object cacheObject = redisCache.getCacheObject(Constants.GZH_MESSAGE_TOKEN);
        //如果过期，重新获取并保存到redis
        if (cacheObject == null){
            String result = wxSendService.getAccessToken("client_credential",appid,secret);
            JSONObject json = JSONObject.parseObject(result);
            String token = json.getString("access_token");
            int expiresIn = json.getIntValue("expires_in");
            redisCache.setCacheObject(Constants.GZH_MESSAGE_TOKEN,token,expiresIn, TimeUnit.SECONDS);
            return token;
        }else {
            return String.valueOf(cacheObject);
        }

    }
}
